#!/bin/bash

installer="ILMT-TAD4D-agent-7.2.1-linux-x86.rpm"
s390installer="ILMT-TAD4D-agent-7.2.1-linux-s390.rpm"
temp_dir=`pwd`
install_dir="$temp_dir/agent/Linux/"
conf_file="response.txt"

while [ $# -ne 0 ]
do
    case $1 in
        -adm_srv_ip*)
            adm_srv_ip=$2
            ;;
        -scan_grp*)
            scan_grp=$2
            ;;
	
    esac
    shift 2
done


if [ ! -d $install_dir ] ; then
	echo "No install dir! Exit"
	exit 1
fi

cd $install_dir

if [ ! -e $conf_file ] ; then
	echo "No response file! Exit"
	exit 1
fi


# First, update administrative server ip if it is defined
if [ ! -z "$adm_srv_ip" ] ; then
    sed -i "s/^MessageHandlerAddress=.*/MessageHandlerAddress=$adm_srv_ip/g" $conf_file 
fi

# Then, update scan group if it is defined
if [ ! -z "$scan_grp" ] ; then
    sed -i "s/^ScanGroup=.*/ScanGroup=$scan_grp/g" $conf_file
fi

# Check hardware platform
if [ $CPU = "s390x" ] ; then
	echo "Using s390x installer."
	installer=$s390installer

    # lets do some 390 magic to the config file

    # active = configured + standby
    systemactiveprocessors=`cat /proc/sysinfo  | awk '/(^CPUs Configured:[ ]+)|(^CPUs Standby:[ ]+)/ { SUM += $3 } END { print SUM }'`
    # cp/ifl
    /sbin/modprobe vmcp
    # wait for device to come online
    while [ ! -c /dev/vmcp ]; 
    do
        echo sleeping till vmcp comes online
        sleep 5
    done

    x=`vmcp q cpus`
    echo $x
    processortype=`echo "$x" | grep "CPU 00" | awk '{print $6}' `
    # z9/z10
    # machinemodel=`cat /proc/cpuinfo  | awk '/machine =/ { print $11 }'`
    machinemodel=`cat /proc/cpuinfo  |  grep -m 1 "machine = " | cut  -d" "  -f 13`
    if [[ "2097 2098" == *$machinemodel* ]]; then
        machinetype="z10"
    else
        machinetype="z9"
    fi
    mount /media/floppy
    chmod +x /media/floppy/hypervisorparms
    . /media/floppy/hypervisorparms
    umount /media/floppy
    cat /proc/sysinfo | grep "LPAR Characteristics:" | grep "Dedicated" > /dev/null
    if [ $? -eq 0 ]; then
        # dedicated cpus, so SHAREDCPUS should be 0
        if [ $SHAREDCPUS -ne 0 ]; then
            echo "error: Detected dedicated cpus, but map admin configured a shared cpus value of $SHAREDCPUS. Please ask map admin to rerun setProperties"
            exit 1
        fi
    else
        # shared cpus
        totalcpus=`cat /proc/sysinfo | grep "LPAR CPUs Total:" | cut -d':' -f2`
        totalcpus=`echo $totalcpus`
        if [ $totalcpus -gt $SHAREDCPUS ]; then
            echo "error: Detected shared cpus, map admin configured a shared cpus value of $SHAREDCPUS which is less than $totalcpus . Please ask map admin to rerun setProperties"
            exit 1
        fi
    fi
    echo SystemActiveProcessors=$systemactiveprocessors SharedPoolCapacity=$SHAREDCPUS ProcessorType=$processortype MachineType=$machinetype
    sed -i "s/^SystemActiveProcessors=.*/SystemActiveProcessors=$systemactiveprocessors/g" $conf_file
    sed -i "s/^SharedPoolCapacity=.*/SharedPoolCapacity=$SHAREDCPUS/g" $conf_file
    sed -i "s/^ProcessorType=.*/ProcessorType=$processortype/g" $conf_file
    sed -i "s/^MachineType=.*/MachineType=$machinetype/g" $conf_file
fi

# Install ILMT in silent mode
if [ ! -e $installer ] ; then
	echo "No installer! Exit"
	exit 1
fi

export LMT_RESPONSE_FILE_PATH=$install_dir$conf_file

echo "Installing $installer"
rpm -ihv $installer
